@@ -1,6 +1,7 @@
 package File::DataClass::Types;
 
-use strictures;
+use strict;
+use warnings;
 
 use File::DataClass::IO;
 use Scalar::Util          qw( blessed dualvar );
@@ -226,7 +227,7 @@ Patches are welcome
 
 =head1 Author
 
-Peter Flanigan, C<< <Support at RoxSoft.co.uk> >>
+Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
